import argparse
from math import pi,sqrt
parser = argparse.ArgumentParser(description="Process cmd command")
parser.add_argument("--L",'-l',dest = "inductance",type = float,help="Inductance of inductor",default=0)
parser.add_argument("--C",'-c',dest = "capacitance",type = float,help="Capacitance of capacitor",default=0)
parser.add_argument("--F",'-f',dest = "frequency",type = float,help="frequency",default=0)

# parser.add_mutually_exclusive_group('')
args = parser.parse_args()

def convert_unit(value):
    if(value>1e6):
        return "%1.2f"%(value/1e6)+"M"
    if(value>1e3):
        return "%1.2f"%(value/1e3)+"k"
    if(value>1):
        return "%1.2f"%value
    if(value>1e-3):
        return "%1.2f"%(value*1e3)+"m"
    if(value>1e-6):
        return "%1.2f"%(value*1e6)+"u"
    if(value>1e-9):
        return "%1.2f"%(value*1e9)+"n"
    if(value>1e-12):
        return "%1.2f"%(value*1e12)+"p"

def main():
    if(args.frequency == 0):
        freq = 1/(2*pi*sqrt(args.inductance*args.capacitance))
        print("Frequency is %s"%convert_unit(freq)+"Hz")
    else:
        if(args.capacitance):
            ind = 1/(2*pi*args.frequency)**2/args.capacitance
            print("Inductor is %s"%convert_unit(ind)+"H")
        else:
            cap = 1/(2*pi*args.frequency)**2/args.inductance
            print("Capacitor is %s"%convert_unit(cap)+"F")

if __name__ == '__main__':
    main()


#-*- encoding: UTF-8 -*-
from setuptools import setup

setup(
    name = "lc_calc",          # 包名
    version = "0.1",              # 版本信息
    packages = ['src'],  # 要打包的项目文件夹
    include_package_data=True,    # 自动打包文件夹内所有数据
    zip_safe=True,                # 设定项目包为安全，不用每次都检测其安全性

    install_requires = [          # 安装依赖的其他包
    'docutils>=0.3',
    'requests',
    ],

    # 设置程序的入口为hello
    # 安装后，命令行执行hello相当于调用hello.py中的main方法
		# 注意其中的等号左边就是命令行输入的名字，右边第一个是包的名字，第二个是包里面py文件的名字，第三个是py文件中调用函数的名字
    entry_points={
        'console_scripts':[
            'lc = src.test:main'
        ]
     },

    # 如果要上传到PyPI，则添加以下信息
    # author = "Me",
    # author_email = "me@example.com",
    # description = "This is an Example Package",
    # license = "MIT",
    # keywords = "hello world example examples",
    # url = "http://example.com/HelloWorld/",   
 )